Pinax Wiki
========================
.. image:: http://slack.pinaxproject.com/badge.svg
   :target: http://slack.pinaxproject.com/

.. image:: https://img.shields.io/travis/pinax/pinax-wiki.svg
    :target: https://travis-ci.org/pinax/pinax-wiki

.. image:: https://img.shields.io/coveralls/pinax/pinax-wiki.svg
    :target: https://coveralls.io/r/pinax/pinax-wiki

.. image:: https://img.shields.io/pypi/dm/pinax-wiki.svg
    :target:  https://pypi.python.org/pypi/pinax-wiki/

.. image:: https://img.shields.io/pypi/v/pinax-wiki.svg
    :target:  https://pypi.python.org/pypi/pinax-wiki/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target:  https://pypi.python.org/pypi/pinax-wiki/


Pinax
------

Pinax is an open-source platform built on the Django Web Framework. It is an ecosystem of reusable Django apps, themes, and starter project templates. 
This collection can be found at http://pinaxproject.com.

This app was developed as part of the Pinax ecosystem but is just a Django app and can be used independently of other Pinax apps.


pinax-wiki
-----------

``pinax-wiki`` lets you easily add a wiki to your Django site.


Running the Tests
------------------------------------

You can run the tests with via::

    python setup.py test

or::

    make test

or::

    make all

or::

    python runtests.py
    

Documentation
---------------

The pinax-wiki documentation is available at http://pinax-wiki.readthedocs.org/en/latest/. The Pinax documentation is available at http://pinaxproject.com/pinax/. If you would like to help us improve our documentation or write more documentation, please join our Pinax Project Slack channel and let us know!


Code of Conduct
----------------

In order to foster a kind, inclusive, and harassment-free community, the Pinax Project has a code of conduct, which can be found here  http://pinaxproject.com/pinax/code_of_conduct/.


Pinax Project Blog and Twitter
--------------------------------

For updates and news regarding the Pinax Project, please follow us on Twitter at @pinaxproject and check out our blog http://blog.pinaxproject.com.




